SystemOrganization addCategory: #FuelCommandLineHandler!

CommandLineHandler subclass: #FLFuelCommandLineHandler
	instanceVariableNames: 'files'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelCommandLineHandler'!

!FLFuelCommandLineHandler commentStamp: '<historical>' prior: 0!
I handle .fuel files that are passed as arguments when starting the image. 

Usage: fuel [save] [quit] <fuelFile>
 
	save    save the image after loading <fuelFile>
	quit    Don't save the image and directly quit the image fater loading <fuelFile>
	
Documentation:
This command will load the <fuelFile> and materialize/install it's contents. If no argument is specified the image continues running with the loaded contents.


Example:

	#Load a fuel file and save and quit the image with the contents:
	./vm.sh Pharo.image save quit path/to/foo.fuel

	#Load the contents of foo.fuel and save the image, but continue running:
	./vm.sh Pharo.image save path/to/foo.fuel
	
	#Load the contents of foo.fuel and continue running without saving:
	./vm.sh Pharo.image path/to/foo.fuel
!

!FLFuelCommandLineHandler class methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 8/4/2012 22:16'!
commandName
	^ 'Fuel'! !

!FLFuelCommandLineHandler class methodsFor: 'accessing' stamp: 'CamilloBruni 2/6/2013 18:18'!
description
	^ 'Loads fuel files'! !

!FLFuelCommandLineHandler class methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 8/4/2012 22:19'!
fileExtension
	^ '.fuel'! !

!FLFuelCommandLineHandler class methodsFor: 'handler selection' stamp: 'MarianoMartinezPeck 8/4/2012 22:18'!
isResponsibleFor: aCommandLine
	"This handler is reponsible only for .fuel files"
	(aCommandLine hasFileWithExtension: self fileExtension)
		ifTrue: [ ^ true ].
	^ super isResponsibleFor: aCommandLine
	! !

!FLFuelCommandLineHandler methodsFor: 'activation' stamp: 'MarianoMartinezPeck 8/21/2012 10:58'!
activate
	self manageFiles.
	(self commandLine hasOption: 'save')
		ifTrue: [
			ThreadSafeTranscript install.
			Smalltalk addDeferredStartupAction: [
				Smalltalk snapshot: true andQuit: true.
				NonInteractiveTranscript new install.
			]
		].
	(self commandLine hasOption: 'quit')
		ifTrue: [ self exitSuccess ].! !

!FLFuelCommandLineHandler methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 8/4/2012 22:14'!
fileExtension
	^ self class fileExtension! !

!FLFuelCommandLineHandler methodsFor: 'manage' stamp: 'MarianoMartinezPeck 8/4/2012 23:46'!
manageFile: aFileReference

	aFileReference readStreamDo: [ :stream |
		stream binary.
		FileStream stdout nextPutAll: 'Materializing from file: ', aFileReference fullName; lf.
		FLMaterializer new materializeFrom: stream.
		FileStream stdout nextPutAll: 'Materialization finished'; lf.
		].! !

!FLFuelCommandLineHandler methodsFor: 'manage' stamp: 'MarianoMartinezPeck 8/4/2012 22:10'!
manageFiles
	"Load all the source files in the given array."
	files := (self commandLine allFilesWithExtension: self fileExtension)
		 collect: [ :each | (FileSystem disk resolve: each) asFileReference ].
	files ifNil: [ ^self ].
	files do: [ :reference | self manageFile: reference ] 
! !
